@@ -42,7 +42,7 @@ from telepathy.interfaces import (CONN_INTERFACE,
 from handle import Handle
 from properties import DBusProperties
 
-from telepathy._generated.Connection import Connection as _Connection
+from _generated.Connection import Connection as _Connection
 
 _BAD = re.compile(r'(?:^[0-9])|(?:[^A-Za-z0-9])')
 
@@ -91,8 +91,11 @@ class Connection(_Connection, DBusProperties):
         self._interfaces = set()
 
         DBusProperties.__init__(self)
-        self._implement_property_get(CONN_INTERFACE,
-                {'SelfHandle': lambda: dbus.UInt32(self.GetSelfHandle())})
+        self._implement_property_get(CONN_INTERFACE, {
+                'SelfHandle': lambda: dbus.UInt32(self.GetSelfHandle()),
+                'Interfaces': lambda: dbus.Array(self.GetInterfaces(), signature='s'),
+                'Status': lambda: dbus.UInt32(self.GetStatus())
+                 })
 
         self._proto = proto
 
@@ -329,15 +332,15 @@ class Connection(_Connection, DBusProperties):
         return ret
 
 
-from telepathy._generated.Connection_Interface_Aliasing \
+from _generated.Connection_Interface_Aliasing \
         import ConnectionInterfaceAliasing
 
 
-from telepathy._generated.Connection_Interface_Avatars \
+from _generated.Connection_Interface_Avatars \
         import ConnectionInterfaceAvatars
 
 
-from telepathy._generated.Connection_Interface_Capabilities \
+from _generated.Connection_Interface_Capabilities \
         import ConnectionInterfaceCapabilities \
         as _ConnectionInterfaceCapabilities
 
@@ -395,7 +398,7 @@ class ConnectionInterfaceCapabilities(_ConnectionInterfaceCapabilities):
         # return all my capabilities
         return [(ctype, caps[1]) for ctype, caps in my_caps.iteritems()]
 
-from telepathy._generated.Connection_Interface_Requests \
+from _generated.Connection_Interface_Requests \
         import ConnectionInterfaceRequests \
         as _ConnectionInterfaceRequests
 
@@ -547,11 +550,11 @@ class ConnectionInterfaceRequests(
 
         self.signal_new_channels([channel])
 
-from telepathy._generated.Connection_Interface_Presence \
+from _generated.Connection_Interface_Presence \
         import ConnectionInterfacePresence
 
-from telepathy._generated.Connection_Interface_Simple_Presence \
+from _generated.Connection_Interface_Simple_Presence \
         import ConnectionInterfaceSimplePresence
 
-from telepathy._generated.Connection_Interface_Contacts \
+from _generated.Connection_Interface_Contacts \
         import ConnectionInterfaceContacts
